@@ -83,7 +83,11 @@ fn process_repository<'a>(
 	config: &mut Config,
 	args: &Opt,
 ) -> Result<Vec<Release<'a>>> {
-	let mut tags = repository.tags(&config.git.tag_pattern, args.topo_order)?;
+	let mut tags = repository.tags(
+		&config.git.tag_pattern,
+		args.topo_order,
+		args.use_branch_tags,
+	)?;
 	let skip_regex = config.git.skip_tags.as_ref();
 	let ignore_regex = config.git.ignore_tags.as_ref();
 	let count_tags = config.git.count_tags.as_ref();
@@ -99,7 +103,7 @@ fn process_repository<'a>(
 		let count = count_tags.map_or(true, |r| {
 			let count_tag = r.is_match(name);
 			if count_tag {
-				trace!("Counting release: {}", name)
+				trace!("Counting release: {}", name);
 			}
 			count_tag
 		});
@@ -111,7 +115,7 @@ fn process_repository<'a>(
 
 			let ignore_tag = r.is_match(name);
 			if ignore_tag {
-				trace!("Ignoring release: {}", name)
+				trace!("Ignoring release: {}", name);
 			}
 			ignore_tag
 		});
@@ -231,21 +235,29 @@ fn process_repository<'a>(
 	}
 
 	// Update tags.
+	let mut releases = vec![Release::default()];
+	let mut tag_timestamp = None;
 	if let Some(ref tag) = args.tag {
 		if let Some(commit_id) = commits.first().map(|c| c.id().to_string()) {
 			match tags.get(&commit_id) {
 				Some(tag) => {
-					warn!("There is already a tag ({:?}) for {}", tag, commit_id)
+					warn!("There is already a tag ({}) for {}", tag.name, commit_id);
+					tag_timestamp = Some(commits[0].time().seconds());
 				}
 				None => {
 					tags.insert(commit_id, repository.resolve_tag(tag));
 				}
 			}
+		} else {
+			releases[0].version = Some(tag.to_string());
+			releases[0].timestamp = SystemTime::now()
+				.duration_since(UNIX_EPOCH)?
+				.as_secs()
+				.try_into()?;
 		}
 	}
 
 	// Process releases.
-	let mut releases = vec![Release::default()];
 	let mut previous_release = Release::default();
 	let mut first_processed_tag = None;
 	for git_commit in commits.iter().rev() {
@@ -259,10 +271,13 @@ fn process_repository<'a>(
 			release.message = tag.message.clone();
 			release.commit_id = Some(commit_id);
 			release.timestamp = if args.tag.as_deref() == Some(tag.name.as_str()) {
-				SystemTime::now()
-					.duration_since(UNIX_EPOCH)?
-					.as_secs()
-					.try_into()?
+				match tag_timestamp {
+					Some(timestamp) => timestamp,
+					None => SystemTime::now()
+						.duration_since(UNIX_EPOCH)?
+						.as_secs()
+						.try_into()?,
+				}
 			} else {
 				git_commit.time().seconds()
 			};
@@ -298,13 +313,6 @@ fn process_repository<'a>(
 			.extend(custom_commits.iter().cloned().map(Commit::from));
 	}
 
-	// Set custom message for the latest release.
-	if let Some(message) = &args.with_tag_message {
-		if let Some(latest_release) = releases.iter_mut().last() {
-			latest_release.message = Some(message.to_owned());
-		}
-	}
-
 	// Set the previous release if the first release does not have one set.
 	if releases[0]
 		.previous
@@ -339,6 +347,17 @@ fn process_repository<'a>(
 		}
 	}
 
+	// Set custom message for the latest release.
+	if let Some(message) = &args.with_tag_message {
+		if let Some(latest_release) = releases
+			.iter_mut()
+			.filter(|release| !release.commits.is_empty())
+			.last()
+		{
+			latest_release.message = Some(message.to_owned());
+		}
+	}
+
 	Ok(releases)
 }
 
@@ -410,12 +429,13 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 		EmbeddedConfig::parse()?
 	};
-	if config.changelog.body.is_none() && !args.context {
+	if config.changelog.body.is_none() && !args.context && !args.bumped_version {
 		warn!("Changelog body is not specified, using the default template.");
 		config.changelog.body = EmbeddedConfig::parse()?.changelog.body;
 	}
 
 	// Update the configuration based on command line arguments and vice versa.
+	let output = args.output.clone().or(config.changelog.output.clone());
 	match args.strip {
 		Some(Strip::Header) => {
 			config.changelog.header = None;
@@ -437,9 +457,9 @@ pub fn run(mut args: Opt) -> Result<()> {
 			)));
 		}
 	}
-	if args.output.is_some() &&
+	if output.is_some() &&
 		args.prepend.is_some() &&
-		args.output.as_ref() == args.prepend.as_ref()
+		output.as_ref() == args.prepend.as_ref()
 	{
 		return Err(Error::ArgumentError(String::from(
 			"'-o' and '-p' can only be used together if they point to different \
@@ -460,6 +480,13 @@ pub fn run(mut args: Opt) -> Result<()> {
 			args.topo_order = topo_order;
 		}
 	}
+
+	if !args.use_branch_tags {
+		if let Some(use_branch_tags) = config.git.use_branch_tags {
+			args.use_branch_tags = use_branch_tags;
+		}
+	}
+
 	if args.github_token.is_some() {
 		config.remote.github.token.clone_from(&args.github_token);
 	}
@@ -524,7 +551,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 
 	// Process commits and releases for the changelog.
 	if let Some(BumpOption::Specific(bump_type)) = args.bump {
-		config.bump.bump_type = Some(bump_type)
+		config.bump.bump_type = Some(bump_type);
 	}
 
 	// Generate changelog from context.
@@ -535,7 +562,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 			Box::new(File::open(context_path)?)
 		};
 		let mut changelog = Changelog::from_context(&mut input, &config)?;
-		changelog.add_remote_data()?;
+		changelog.add_remote_context()?;
 		changelog
 	} else {
 		// Process the repositories.
@@ -564,7 +591,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 						sha: Some(sha1.to_string()),
 						skip: Some(true),
 						..Default::default()
-					})
+					});
 				}
 			}
 
@@ -580,7 +607,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	};
 
 	// Print the result.
-	let mut out: Box<dyn io::Write> = if let Some(path) = &args.output {
+	let mut out: Box<dyn io::Write> = if let Some(path) = &output {
 		if path == Path::new("-") {
 			Box::new(io::stdout())
 		} else {
@@ -616,7 +643,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		let mut out = io::BufWriter::new(File::create(path)?);
 		changelog.prepend(changelog_before, &mut out)?;
 	}
-	if args.output.is_some() || args.prepend.is_none() {
+	if output.is_some() || args.prepend.is_none() {
 		changelog.generate(&mut out)?;
 	}
 
